# DataPipes

DataPipes for open data



## Installation

```bash
pip install datapipes
```



## Quick Start

```python
import datapipes
```



## Contributing



## License

DataPipes has an BSD-3-Clause license, as found in the [LICENSE](https://github.com/opencovid19data/opendata/blob/main/LICENSE) file.
